@@ -605,3 +605,27 @@ def getXorgConfContent(prefix="/"):
                      [path.join(prefix, "etc/X11/xorg.conf")] + 
                      glob.glob(path.join(prefix,"etc/X11/xorg.conf.d/*"))
                      if path.isfile(x))
+
+def get_fastlogin_domain_path(dv):
+    """
+    Получить пути до ресурсов для определения нужно ли выполнять
+    шаблоны для доменного профиля пользователя
+    """
+    from calculate.lib.cl_template import LayeredIni
+    overlay_suffix_path = 'profiles/templates'
+    template_paths = dv.Get('main.cl_template_path')
+    for template_path in template_paths:
+        if template_path.endswith(overlay_suffix_path):
+            template_path = template_path[:-len(overlay_suffix_path)-1]
+        yield os.path.join(template_path, ".git")
+    for envfile in (LayeredIni.IniPath.System,
+        LayeredIni.IniPath.Etc,
+        LayeredIni.IniPath.Local,
+        LayeredIni.IniPath.Remote):
+        yield envfile
+    for cenvfile in ("/etc/calculate/calculate.env",
+        "/var/calculate/calculate.env",
+        "/var/lib/calculate/calculate.env",
+        "/var/calculate/remote/calculate.env"):
+        yield cenvfile
+    yield "/var/log/emerge.log"
